@@ -26,21 +26,28 @@ from .types.cloud_filestore_service import (
     Backup,
     CreateBackupRequest,
     CreateInstanceRequest,
+    CreateSnapshotRequest,
     DeleteBackupRequest,
     DeleteInstanceRequest,
+    DeleteSnapshotRequest,
     FileShareConfig,
     GetBackupRequest,
     GetInstanceRequest,
+    GetSnapshotRequest,
     Instance,
     ListBackupsRequest,
     ListBackupsResponse,
     ListInstancesRequest,
     ListInstancesResponse,
+    ListSnapshotsRequest,
+    ListSnapshotsResponse,
     NetworkConfig,
     NfsExportOptions,
     RestoreInstanceRequest,
+    Snapshot,
     UpdateBackupRequest,
     UpdateInstanceRequest,
+    UpdateSnapshotRequest,
 )
 
 __all__ = (
@@ -49,19 +56,26 @@ __all__ = (
     "CloudFilestoreManagerClient",
     "CreateBackupRequest",
     "CreateInstanceRequest",
+    "CreateSnapshotRequest",
     "DeleteBackupRequest",
     "DeleteInstanceRequest",
+    "DeleteSnapshotRequest",
     "FileShareConfig",
     "GetBackupRequest",
     "GetInstanceRequest",
+    "GetSnapshotRequest",
     "Instance",
     "ListBackupsRequest",
     "ListBackupsResponse",
     "ListInstancesRequest",
     "ListInstancesResponse",
+    "ListSnapshotsRequest",
+    "ListSnapshotsResponse",
     "NetworkConfig",
     "NfsExportOptions",
     "RestoreInstanceRequest",
+    "Snapshot",
     "UpdateBackupRequest",
     "UpdateInstanceRequest",
+    "UpdateSnapshotRequest",
 )
