@@ -61,12 +61,12 @@ from .transports.grpc_asyncio import CloudFilestoreManagerGrpcAsyncIOTransport
 
 
 class CloudFilestoreManagerAsyncClient:
-    """Configures and manages Cloud Filestore resources.
+    """Configures and manages Filestore resources.
 
-    Cloud Filestore Manager v1.
+    Filestore Manager v1.
 
-    The ``file.googleapis.com`` service implements the Cloud Filestore
-    API and defines the following resource model for managing instances:
+    The ``file.googleapis.com`` service implements the Filestore API and
+    defines the following resource model for managing instances:
 
     -  The service works with a collection of cloud projects, named:
        ``/projects/*``
@@ -74,13 +74,13 @@ class CloudFilestoreManagerAsyncClient:
        ``/locations/*``
     -  Each location has a collection of instances and backups, named:
        ``/instances/*`` and ``/backups/*`` respectively.
-    -  As such, Cloud Filestore instances are resources of the form:
+    -  As such, Filestore instances are resources of the form:
        ``/projects/{project_number}/locations/{location_id}/instances/{instance_id}``
        and backups are resources of the form:
        ``/projects/{project_number}/locations/{location_id}/backup/{backup_id}``
 
-    Note that location_id must be a GCP ``zone`` for instances and but
-    to a GCP ``region`` for backups; for example:
+    Note that location_id must be a Google Cloud ``zone`` for instances,
+    but a Google Cloud ``region`` for backups; for example:
 
     -  ``projects/12345/locations/us-central1-c/instances/my-filestore``
     -  ``projects/12345/locations/us-central1/backups/my-backup``
@@ -95,6 +95,8 @@ class CloudFilestoreManagerAsyncClient:
     parse_backup_path = staticmethod(CloudFilestoreManagerClient.parse_backup_path)
     instance_path = staticmethod(CloudFilestoreManagerClient.instance_path)
     parse_instance_path = staticmethod(CloudFilestoreManagerClient.parse_instance_path)
+    snapshot_path = staticmethod(CloudFilestoreManagerClient.snapshot_path)
+    parse_snapshot_path = staticmethod(CloudFilestoreManagerClient.parse_snapshot_path)
     common_billing_account_path = staticmethod(
         CloudFilestoreManagerClient.common_billing_account_path
     )
@@ -295,15 +297,14 @@ class CloudFilestoreManagerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.filestore_v1.types.ListInstancesRequest, dict]]):
-                The request object. ListInstancesRequest lists
-                instances.
+                The request object. ListInstancesRequest lists instances.
             parent (:class:`str`):
                 Required. The project and location for which to retrieve
                 instance information, in the format
                 ``projects/{project_id}/locations/{location}``. In Cloud
-                Filestore, locations map to GCP zones, for example
-                **us-west1-b**. To retrieve instance information for all
-                locations, use "-" for the ``{location}`` value.
+                Filestore, locations map to Google Cloud zones, for
+                example **us-west1-b**. To retrieve instance information
+                for all locations, use "-" for the ``{location}`` value.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -441,7 +442,7 @@ class CloudFilestoreManagerAsyncClient:
 
         Returns:
             google.cloud.filestore_v1.types.Instance:
-                A Cloud Filestore instance.
+                A Filestore instance.
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -551,7 +552,7 @@ class CloudFilestoreManagerAsyncClient:
             parent (:class:`str`):
                 Required. The instance's project and location, in the
                 format ``projects/{project_id}/locations/{location}``.
-                In Cloud Filestore, locations map to GCP zones, for
+                In Filestore, locations map to Google Cloud zones, for
                 example **us-west1-b**.
 
                 This corresponds to the ``parent`` field
@@ -584,7 +585,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.filestore_v1.types.Instance` A
-                Cloud Filestore instance.
+                Filestore instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -717,7 +718,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.filestore_v1.types.Instance` A
-                Cloud Filestore instance.
+                Filestore instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -825,7 +826,8 @@ class CloudFilestoreManagerAsyncClient:
         Args:
             request (Optional[Union[google.cloud.filestore_v1.types.RestoreInstanceRequest, dict]]):
                 The request object. RestoreInstanceRequest restores an
-                existing instances's file share from a backup.
+                existing instance's file share from a
+                backup.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -838,7 +840,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.filestore_v1.types.Instance` A
-                Cloud Filestore instance.
+                Filestore instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -1003,6 +1005,626 @@ class CloudFilestoreManagerAsyncClient:
         # Done; return the response.
         return response
 
+    async def list_snapshots(
+        self,
+        request: Optional[
+            Union[cloud_filestore_service.ListSnapshotsRequest, dict]
+        ] = None,
+        *,
+        parent: Optional[str] = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> pagers.ListSnapshotsAsyncPager:
+        r"""Lists all snapshots in a project for either a
+        specified location or for all locations.
+
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import filestore_v1
+
+            async def sample_list_snapshots():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.ListSnapshotsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_snapshots(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
+        Args:
+            request (Optional[Union[google.cloud.filestore_v1.types.ListSnapshotsRequest, dict]]):
+                The request object. ListSnapshotsRequest lists snapshots.
+            parent (:class:`str`):
+                Required. The instance for which to retrieve snapshot
+                information, in the format
+                ``projects/{project_id}/locations/{location}/instances/{instance_id}``.
+
+                This corresponds to the ``parent`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.filestore_v1.services.cloud_filestore_manager.pagers.ListSnapshotsAsyncPager:
+                ListSnapshotsResponse is the result
+                of ListSnapshotsRequest.
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_filestore_service.ListSnapshotsRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if parent is not None:
+            request.parent = parent
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.list_snapshots,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__aiter__` convenience method.
+        response = pagers.ListSnapshotsAsyncPager(
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def get_snapshot(
+        self,
+        request: Optional[
+            Union[cloud_filestore_service.GetSnapshotRequest, dict]
+        ] = None,
+        *,
+        name: Optional[str] = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> cloud_filestore_service.Snapshot:
+        r"""Gets the details of a specific snapshot.
+
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import filestore_v1
+
+            async def sample_get_snapshot():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.GetSnapshotRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_snapshot(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Optional[Union[google.cloud.filestore_v1.types.GetSnapshotRequest, dict]]):
+                The request object. GetSnapshotRequest gets the state of
+                a snapshot.
+            name (:class:`str`):
+                Required. The snapshot resource name, in the format
+                ``projects/{project_id}/locations/{location}/instances/{instance_id}/snapshots/{snapshot_id}``
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.filestore_v1.types.Snapshot:
+                A Filestore snapshot.
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_filestore_service.GetSnapshotRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.get_snapshot,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def create_snapshot(
+        self,
+        request: Optional[
+            Union[cloud_filestore_service.CreateSnapshotRequest, dict]
+        ] = None,
+        *,
+        parent: Optional[str] = None,
+        snapshot: Optional[cloud_filestore_service.Snapshot] = None,
+        snapshot_id: Optional[str] = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Creates a snapshot.
+
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import filestore_v1
+
+            async def sample_create_snapshot():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.CreateSnapshotRequest(
+                    parent="parent_value",
+                    snapshot_id="snapshot_id_value",
+                )
+
+                # Make the request
+                operation = client.create_snapshot(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = (await operation).result()
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Optional[Union[google.cloud.filestore_v1.types.CreateSnapshotRequest, dict]]):
+                The request object. CreateSnapshotRequest creates a
+                snapshot.
+            parent (:class:`str`):
+                Required. The Filestore Instance to create the snapshots
+                of, in the format
+                ``projects/{project_id}/locations/{location}/instances/{instance_id}``
+
+                This corresponds to the ``parent`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            snapshot (:class:`google.cloud.filestore_v1.types.Snapshot`):
+                Required. A snapshot resource.
+                This corresponds to the ``snapshot`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            snapshot_id (:class:`str`):
+                Required. The ID to use for the
+                snapshot. The ID must be unique within
+                the specified instance.
+                This value must start with a lowercase
+                letter followed by up to 62 lowercase
+                letters, numbers, or hyphens, and cannot
+                end with a hyphen.
+
+                This corresponds to the ``snapshot_id`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be
+                :class:`google.cloud.filestore_v1.types.Snapshot` A
+                Filestore snapshot.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([parent, snapshot, snapshot_id])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_filestore_service.CreateSnapshotRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if parent is not None:
+            request.parent = parent
+        if snapshot is not None:
+            request.snapshot = snapshot
+        if snapshot_id is not None:
+            request.snapshot_id = snapshot_id
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.create_snapshot,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            cloud_filestore_service.Snapshot,
+            metadata_type=operation_metadata_pb2.OperationMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def delete_snapshot(
+        self,
+        request: Optional[
+            Union[cloud_filestore_service.DeleteSnapshotRequest, dict]
+        ] = None,
+        *,
+        name: Optional[str] = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Deletes a snapshot.
+
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import filestore_v1
+
+            async def sample_delete_snapshot():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.DeleteSnapshotRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_snapshot(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = (await operation).result()
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Optional[Union[google.cloud.filestore_v1.types.DeleteSnapshotRequest, dict]]):
+                The request object. DeleteSnapshotRequest deletes a
+                snapshot.
+            name (:class:`str`):
+                Required. The snapshot resource name, in the format
+                ``projects/{project_id}/locations/{location}/instances/{instance_id}/snapshots/{snapshot_id}``
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
+
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
+
+                      }
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_filestore_service.DeleteSnapshotRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.delete_snapshot,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            empty_pb2.Empty,
+            metadata_type=operation_metadata_pb2.OperationMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def update_snapshot(
+        self,
+        request: Optional[
+            Union[cloud_filestore_service.UpdateSnapshotRequest, dict]
+        ] = None,
+        *,
+        snapshot: Optional[cloud_filestore_service.Snapshot] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Updates the settings of a specific snapshot.
+
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import filestore_v1
+
+            async def sample_update_snapshot():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.UpdateSnapshotRequest(
+                )
+
+                # Make the request
+                operation = client.update_snapshot(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = (await operation).result()
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Optional[Union[google.cloud.filestore_v1.types.UpdateSnapshotRequest, dict]]):
+                The request object. UpdateSnapshotRequest updates
+                description and/or labels for a
+                snapshot.
+            snapshot (:class:`google.cloud.filestore_v1.types.Snapshot`):
+                Required. A snapshot resource.
+                This corresponds to the ``snapshot`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
+                Required. Mask of fields to update.
+                At least one path must be supplied in
+                this field.
+
+                This corresponds to the ``update_mask`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be
+                :class:`google.cloud.filestore_v1.types.Snapshot` A
+                Filestore snapshot.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([snapshot, update_mask])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_filestore_service.UpdateSnapshotRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if snapshot is not None:
+            request.snapshot = snapshot
+        if update_mask is not None:
+            request.update_mask = update_mask
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.update_snapshot,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("snapshot.name", request.snapshot.name),)
+            ),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            cloud_filestore_service.Snapshot,
+            metadata_type=operation_metadata_pb2.OperationMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def list_backups(
         self,
         request: Optional[
@@ -1051,7 +1673,7 @@ class CloudFilestoreManagerAsyncClient:
                 Required. The project and location for which to retrieve
                 backup information, in the format
                 ``projects/{project_number}/locations/{location}``. In
-                Cloud Filestore, backup locations map to GCP regions,
+                Filestore, backup locations map to Google Cloud regions,
                 for example **us-west1**. To retrieve backup information
                 for all locations, use "-" for the ``{location}`` value.
 
@@ -1189,7 +1811,7 @@ class CloudFilestoreManagerAsyncClient:
 
         Returns:
             google.cloud.filestore_v1.types.Backup:
-                A Cloud Filestore backup.
+                A Filestore backup.
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1290,13 +1912,12 @@ class CloudFilestoreManagerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.filestore_v1.types.CreateBackupRequest, dict]]):
-                The request object. CreateBackupRequest creates a
-                backup.
+                The request object. CreateBackupRequest creates a backup.
             parent (:class:`str`):
                 Required. The backup's project and location, in the
                 format
                 ``projects/{project_number}/locations/{location}``. In
-                Cloud Filestore, backup locations map to GCP regions,
+                Filestore, backup locations map to Google Cloud regions,
                 for example **us-west1**.
 
                 This corresponds to the ``parent`` field
@@ -1332,7 +1953,7 @@ class CloudFilestoreManagerAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.filestore_v1.types.Backup` A Cloud
+                :class:`google.cloud.filestore_v1.types.Backup` A
                 Filestore backup.
 
         """
@@ -1435,8 +2056,7 @@ class CloudFilestoreManagerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.filestore_v1.types.DeleteBackupRequest, dict]]):
-                The request object. DeleteBackupRequest deletes a
-                backup.
+                The request object. DeleteBackupRequest deletes a backup.
             name (:class:`str`):
                 Required. The backup resource name, in the format
                 ``projects/{project_number}/locations/{location}/backups/{backup_id}``
@@ -1589,7 +2209,7 @@ class CloudFilestoreManagerAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.filestore_v1.types.Backup` A Cloud
+                :class:`google.cloud.filestore_v1.types.Backup` A
                 Filestore backup.
 
         """
